import * as react_jsx_runtime from 'react/jsx-runtime';

declare const BUBBLE_CLASSNAME = "av-bubble";

type BubbleProps = {
	/**
	 * The text to render in the bubble.
	 */
	children: React.ReactNode;
	/**
	 * CSS class(es) to add to the main component wrapper.
	 */
	className?: string;
	/**
	 * Whether or not to show a "copy/paste" icon next to the Bubble.
	 * - If a function is passed, it will be called with the text to copy.
	 * - If a string is passed, that string will be copied.
	 * - If a boolean is passed, the children will be copied.
	 */
	copyToClipboard?: boolean | string | ((text: any) => void);
	/**
	 * The type of focus for the Copy Button. This will change the color
	 * of the focus ring around the Button.
	 */
	copyToClipboardFocusMode?: "dark" | "light" | "system" | "alt-system";
	/**
	 * The mode of Copy Button. This will change the color of the Button.
	 */
	copyToClipboardMode?: "dark" | "light" | "system" | "alt-system";
	/**
	 * Object depicting the extra rows for the Bubble.
	 * @example
	 * ```tsx
	 * <Bubble
	 * 	footer={{
	 * 		"Sent": "12:00 PM",
	 * 		"Delivered": "12:01 PM",
	 * 		"Read": "12:02 PM",
	 * 	}}
	 * >Hello World</Bubble>
	 * ```
	 */
	footer?: {
		[key: string]: string | number | undefined | null;
	};
	/**
	 * The type of Bubble. This will change the color of the Bubble
	 * as well as the chevron location.
	 */
	kind?: "left" | "right";
	/**
	 * Same as "footer" but accepts raw JSX.
	 */
	rawFooter?: React.ReactNode;
	/**
	 * Whether or not the Bubble should have a default max-width.
	 * By default, bubble width will be responsive to the viewport,
	 * but in some cases, it may be useful to disable this behavior
	 * and allow the Bubble to grow to its content.
	 * You can also provide your own container class to control the width,
	 * based on the container's width.
	 * @see https://css-tricks.com/css-container-queries/#aa-container-length-units
	 *
	 * @example
	 * ```tsx
	 * <div> // this div should be declared as a container
	 *   <Bubble kind="left" noMaxWidth className="max-w-[95qcw]">
	 *     Hello World
	 *   </Bubble>
	 * </div>
	 * ```
	 * @default false
	 */
	noMaxWidth?: boolean;
};

declare const Bubble: ({ children, kind, className, footer, rawFooter, copyToClipboard, copyToClipboardFocusMode, copyToClipboardMode, noMaxWidth, }: BubbleProps) => react_jsx_runtime.JSX.Element;

export { BUBBLE_CLASSNAME, Bubble };
